@@ -1,7 +1,7 @@
 import inspect
 from collections.abc import Callable, Sequence
 from enum import Enum
-from typing import Any, Literal
+from typing import TYPE_CHECKING, Any, Literal
 
 from pydantic._internal._utils import lenient_issubclass
 from pydantic.main import IncEx
@@ -34,6 +34,10 @@ from wellapi.routing import (
     is_body_allowed_for_status_code,
     request_response,
 )
+from wellapi.telemetry.telemetry import Telemetry
+
+if TYPE_CHECKING:
+    from opentelemetry.trace import Span
 
 
 def to_camel_case(snake_str):
@@ -57,6 +61,8 @@ class Lambda:
         name: str | None = None,
         memory_size: int = 128,
         timeout: int = 30,
+        fifo: bool | None = None,
+        warmup: bool | None = None,
         response_model: Any = Default(None),
         status_code: int | None = None,
         description: str | None = None,
@@ -83,6 +89,8 @@ class Lambda:
         self.name = endpoint.__name__ if name is None else name
         self.memory_size = memory_size
         self.timeout = timeout
+        self.fifo = fifo
+        self.warmup = warmup
         self.method = method
         self.endpoint = endpoint
         self.cache_parameters = cache_parameters
@@ -198,6 +206,8 @@ class WellApi:
         servers: list[dict[str, str | Any]] | None = None,
         queues: list[dict[str, Any]] | None = None,
         debug: bool = False,
+        memory_size: int = 128,
+        timeout: int = 30,
     ):
         self.lambdas = []
         self.exception_handlers = {}
@@ -213,6 +223,18 @@ class WellApi:
         self.openapi_tags = openapi_tags
         self.servers = servers
         self.queues = queues or []
+        self.memory_size = memory_size
+        self.timeout = timeout
+        # Telemetry (optional, only if extras installed)
+        self.telemetry = None
+        self.request_hook = None
+        self.response_hook = None
+
+    async def __call__(self, scope, receive, send) -> None:
+        from wellapi.local.server import handel_local
+
+        scope["app"] = self
+        await handel_local(scope, receive, send)
 
     def build_middleware_stack(self, app: Callable) -> Callable:
         debug = self.debug
@@ -237,6 +259,22 @@ class WellApi:
             ]
         )
 
+        # Insert telemetry just after the server error middleware so it wraps
+        # app logic but still benefits from top-level error handling.
+        if self.telemetry is not None:
+            # Import lazily to avoid requiring telemetry extras unless used.
+            from wellapi.telemetry.middleware import TelemetryMiddleware
+
+            middleware.insert(
+                1,
+                Middleware(
+                    TelemetryMiddleware,
+                    telemetry=self.telemetry,
+                    request_hook=self.request_hook,
+                    response_hook=self.response_hook,
+                ),
+            )
+
         for cls, args, kwargs in reversed(middleware):
             app = cls(app, *args, **kwargs)
         return request_response(app)
@@ -245,10 +283,7 @@ class WellApi:
         lambda_ = Lambda(*args, **kwargs)
         self.lambdas.append(lambda_)
 
-        def endpoint(event, context):
-            return self.build_middleware_stack(lambda_.app)(event, context)
-
-        return endpoint
+        return self.build_middleware_stack(lambda_.app)
 
     def add_exception_handler(
         self,
@@ -276,6 +311,16 @@ class WellApi:
 
         return decorator
 
+    def use_telemetry(
+        self,
+        telemetry: Telemetry,
+        request_hook: Callable[["Span", RequestAPIGateway], None] | None = None,
+        response_hook: Callable[["Span", ResponseAPIGateway | None], None] | None = None,
+    ) -> None:
+        self.telemetry = telemetry
+        self.request_hook = request_hook
+        self.response_hook = response_hook
+
     def get(
         self,
         path: str,
@@ -283,8 +328,10 @@ class WellApi:
         response_model: Any = Default(None),
         status_code: int | None = None,
         cache_parameters: params.Cache | None = None,
-        memory_size: int = 128,
-        timeout: int = 30,
+        memory_size: int | None = None,
+        timeout: int | None = None,
+        warmup: bool | None = None,
+        responses: dict[int | str, dict[str, Any]] | None = None,
         response_class: type[ResponseAPIGateway] | DefaultPlaceholder = Default(
             ResponseAPIGateway
         ),
@@ -306,8 +353,10 @@ class WellApi:
                 status_code=status_code,
                 method="GET",
                 cache_parameters=cache_parameters,
-                memory_size=memory_size,
-                timeout=timeout,
+                memory_size=memory_size or self.memory_size,
+                timeout=timeout or self.timeout,
+                warmup=warmup,
+                responses=responses,
                 response_class=response_class,
                 response_model_include=response_model_include,
                 response_model_exclude=response_model_exclude,
@@ -329,8 +378,10 @@ class WellApi:
         response_model: Any = Default(None),
         status_code: int | None = None,
         cache_parameters: params.Cache | None = None,
-        memory_size: int = 128,
-        timeout: int = 30,
+        memory_size: int | None = None,
+        timeout: int | None = None,
+        warmup: bool | None = None,
+        responses: dict[int | str, dict[str, Any]] | None = None,
         response_class: type[ResponseAPIGateway] | DefaultPlaceholder = Default(
             ResponseAPIGateway
         ),
@@ -352,8 +403,10 @@ class WellApi:
                 status_code=status_code,
                 method="POST",
                 cache_parameters=cache_parameters,
-                memory_size=memory_size,
-                timeout=timeout,
+                memory_size=memory_size or self.memory_size,
+                timeout=timeout or self.timeout,
+                warmup=warmup,
+                responses=responses,
                 response_class=response_class,
                 response_model_include=response_model_include,
                 response_model_exclude=response_model_exclude,
@@ -375,8 +428,10 @@ class WellApi:
         response_model: Any = Default(None),
         status_code: int | None = None,
         cache_parameters: params.Cache | None = None,
-        memory_size: int = 128,
-        timeout: int = 30,
+        memory_size: int | None = None,
+        timeout: int | None = None,
+        warmup: bool | None = None,
+        responses: dict[int | str, dict[str, Any]] | None = None,
         response_class: type[ResponseAPIGateway] | DefaultPlaceholder = Default(
             ResponseAPIGateway
         ),
@@ -398,8 +453,10 @@ class WellApi:
                 status_code=status_code,
                 method="PUT",
                 cache_parameters=cache_parameters,
-                memory_size=memory_size,
-                timeout=timeout,
+                memory_size=memory_size or self.memory_size,
+                timeout=timeout or self.timeout,
+                warmup=warmup,
+                responses=responses,
                 response_class=response_class,
                 response_model_include=response_model_include,
                 response_model_exclude=response_model_exclude,
@@ -421,8 +478,10 @@ class WellApi:
         response_model: Any = Default(None),
         status_code: int | None = None,
         cache_parameters: params.Cache | None = None,
-        memory_size: int = 128,
-        timeout: int = 30,
+        memory_size: int | None = None,
+        timeout: int | None = None,
+        warmup: bool | None = None,
+        responses: dict[int | str, dict[str, Any]] | None = None,
         response_class: type[ResponseAPIGateway] | DefaultPlaceholder = Default(
             ResponseAPIGateway
         ),
@@ -444,8 +503,10 @@ class WellApi:
                 status_code=status_code,
                 method="PATCH",
                 cache_parameters=cache_parameters,
-                memory_size=memory_size,
-                timeout=timeout,
+                memory_size=memory_size or self.memory_size,
+                timeout=timeout or self.timeout,
+                warmup=warmup,
+                responses=responses,
                 response_class=response_class,
                 response_model_include=response_model_include,
                 response_model_exclude=response_model_exclude,
@@ -467,8 +528,10 @@ class WellApi:
         response_model: Any = Default(None),
         status_code: int | None = None,
         cache_parameters: params.Cache | None = None,
-        memory_size: int = 128,
-        timeout: int = 30,
+        memory_size: int | None = None,
+        timeout: int | None = None,
+        warmup: bool | None = None,
+        responses: dict[int | str, dict[str, Any]] | None = None,
         response_class: type[ResponseAPIGateway] | DefaultPlaceholder = Default(
             ResponseAPIGateway
         ),
@@ -490,8 +553,10 @@ class WellApi:
                 status_code=status_code,
                 method="DELETE",
                 cache_parameters=cache_parameters,
-                memory_size=memory_size,
-                timeout=timeout,
+                memory_size=memory_size or self.memory_size,
+                timeout=timeout or self.timeout,
+                warmup=warmup,
+                responses=responses,
                 response_class=response_class,
                 response_model_include=response_model_include,
                 response_model_exclude=response_model_exclude,
@@ -510,8 +575,9 @@ class WellApi:
         self,
         queue_name: str,
         *,
-        memory_size: int = 128,
-        timeout: int = 30,
+        memory_size: int | None = None,
+        timeout: int | None = None,
+        fifo: bool | None = None,
         dependencies: Sequence[params.Depends] | None = None,
     ):
         def decorator(func):
@@ -519,8 +585,9 @@ class WellApi:
                 queue_name,
                 func,
                 type_="queue",
-                memory_size=memory_size,
-                timeout=timeout,
+                memory_size=memory_size or self.memory_size,
+                timeout=timeout or self.timeout,
+                fifo=fifo,
                 dependencies=dependencies,
             )
             return lambda_
@@ -532,7 +599,7 @@ class WellApi:
         expression: str,
         *,
         name: str | None = None,
-        memory_size: int = 128,
+        memory_size: int | None = None,
         timeout: int = 30,
         dependencies: Sequence[params.Depends] | None = None,
     ):
@@ -542,8 +609,8 @@ class WellApi:
                 func,
                 type_="job",
                 name=name,
-                memory_size=memory_size,
-                timeout=timeout,
+                memory_size=memory_size or self.memory_size,
+                timeout=timeout or self.timeout,
                 dependencies=dependencies,
             )
             return lambda_
