@@ -1,10 +1,11 @@
+import os
 import sys
 from collections.abc import Callable
 from enum import Enum
 
 from wellapi.applications import Lambda
 from wellapi.routing import compile_path
-from wellapi.utils import import_app
+from wellapi.utils import load_handlers
 
 
 class Match(Enum):
@@ -49,6 +50,8 @@ class Route:
         return f"Route(path={self.path}, method={self.method})"
 
     def __call__(self, *args, **kwargs):
+        os.environ["_HANDLER"] = f"{self.endpoint_module}.{self.endpoint_name}"
+
         module = sys.modules[self.endpoint_module]
         return getattr(module, self.endpoint_name)(*args, **kwargs)
 
@@ -70,20 +73,23 @@ class Route:
 
 
 class Router:
-    def __init__(self):
+    def __init__(self, app=None, path_to_handlers_dir: str | None = None):
         self.routes: list[Route] = []
+        self.app = app
+        self.path_to_handlers_dir = path_to_handlers_dir or "handlers"
+        self.discover_handlers()
 
     def add_route(self, path: str, method: str, function: Callable):
         route = Route(path, function, method)
         self.routes.append(route)
         return route
 
-    def discover_handlers(self, app_srt, path_to_handlers_dir):
-        app = import_app(app_srt, path_to_handlers_dir)
+    def discover_handlers(self):
+        load_handlers(self.path_to_handlers_dir)
 
         self.routes = []
         e: Lambda
-        for e in app.lambdas:
+        for e in self.app.lambdas:
             path = e.path
             method = e.method
             if e.type_ == "queue":
