@@ -1,13 +1,14 @@
 from collections.abc import Callable, Sequence
 from enum import Enum
-from typing import Any
+from typing import Any, TYPE_CHECKING
 
 from pydantic import AliasChoices, AliasPath
 from pydantic.fields import FieldInfo
 from pydantic_core import PydanticUndefined
 from typing_extensions import deprecated
 
-from wellapi.openapi.models import Example, ParameterInType
+if TYPE_CHECKING:
+    from wellapi.openapi.models import Example
 
 _Unset: Any = PydanticUndefined
 
@@ -48,7 +49,7 @@ class Param(FieldInfo):
         max_digits: int | None = _Unset,
         decimal_places: int | None = _Unset,
         examples: list[Any] | None = None,
-        openapi_examples: dict[str, Example] | None = None,
+        openapi_examples: dict[str, "Example"] | None = None,
         deprecated: deprecated | str | bool | None = None,
         include_in_schema: bool = True,
         json_schema_extra: dict[str, Any] | None = None,
@@ -130,7 +131,7 @@ class Path(Param):
         max_digits: int | None = _Unset,
         decimal_places: int | None = _Unset,
         examples: list[Any] | None = None,
-        openapi_examples: dict[str, Example] | None = None,
+        openapi_examples: dict[str, "Example"] | None = None,
         deprecated: deprecated | str | bool | None = None,
         include_in_schema: bool = True,
         json_schema_extra: dict[str, Any] | None = None,
@@ -199,7 +200,7 @@ class Query(Param):
         max_digits: int | None = _Unset,
         decimal_places: int | None = _Unset,
         examples: list[Any] | None = None,
-        openapi_examples: dict[str, Example] | None = None,
+        openapi_examples: dict[str, "Example"] | None = None,
         deprecated: deprecated | str | bool | None = None,
         include_in_schema: bool = True,
         json_schema_extra: dict[str, Any] | None = None,
@@ -267,7 +268,7 @@ class Header(Param):
         max_digits: int | None = _Unset,
         decimal_places: int | None = _Unset,
         examples: list[Any] | None = None,
-        openapi_examples: dict[str, Example] | None = None,
+        openapi_examples: dict[str, "Example"] | None = None,
         deprecated: deprecated | str | bool | None = None,
         include_in_schema: bool = True,
         json_schema_extra: dict[str, Any] | None = None,
@@ -335,7 +336,7 @@ class Cookie(Param):
         max_digits: int | None = _Unset,
         decimal_places: int | None = _Unset,
         examples: list[Any] | None = None,
-        openapi_examples: dict[str, Example] | None = None,
+        openapi_examples: dict[str, "Example"] | None = None,
         deprecated: deprecated | str | bool | None = None,
         include_in_schema: bool = True,
         json_schema_extra: dict[str, Any] | None = None,
@@ -402,7 +403,7 @@ class Body(FieldInfo):
         max_digits: int | None = _Unset,
         decimal_places: int | None = _Unset,
         examples: list[Any] | None = None,
-        openapi_examples: dict[str, Example] | None = None,
+        openapi_examples: dict[str, "Example"] | None = None,
         deprecated: deprecated | str | bool | None = None,
         include_in_schema: bool = True,
         json_schema_extra: dict[str, Any] | None = None,
@@ -501,6 +502,9 @@ class Cache:
         self.header = header or []
 
     def __iter__(self):
+        # Use lazy import to avoid heavy imports
+        from wellapi.openapi.models import ParameterInType
+
         res = []
         for p in self.path:
             res.append((p, ParameterInType.path, "path"))
